==========
Changelog
==========

This project adheres to `Semantic Versioning <https://semver.org/>`_.


1.0.0 (2021-08-10)
------------------

**Added**

**Fixed**

**Dependencies**

**Deprecated**


0.1.0 (2021-08-10)
------------------

**Added**

* Created the project using mlf-core

**Fixed**

**Dependencies**

**Deprecated**
